==> haskell-crypton-x509-store-1.6.11-34-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-crypton-x509-store.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 crypton-x509-store
version:              1.6.11
visibility:           public
id:                   crypton-x509-store-1.6.11-FlL0X1cDhlF6pM7lUoQOjH
key:                  crypton-x509-store-1.6.11-FlL0X1cDhlF6pM7lUoQOjH
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/kazu-yamamoto/crypton-certificate
synopsis:             X.509 collection accessing and storing methods
description:
    X.509 collection accessing and storing methods for certificate, crl, exception list

category:             Data
abi:                  a8f10604b89df10b6a13604a11326530
exposed:              True
exposed-modules:
    Data.X509.CertificateStore Data.X509.File Data.X509.Memory

import-dirs:          /usr/lib/ghc-9.4.8/site-local/crypton-x509-store-1.6.11
library-dirs:         /usr/lib/ghc-9.4.8/site-local/crypton-x509-store-1.6.11
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/crypton-x509-store-1.6.11
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypton-x509-store
hs-libraries:         HScrypton-x509-store-1.6.11-FlL0X1cDhlF6pM7lUoQOjH
depends:
    asn1-encoding-0.9.6-CAwjlK8uWKv9dM99cgE2ve
    asn1-types-0.3.4-1FzZRhS4KrvH9STpZDYz6S base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7
    crypton-1.0.4-3OO0UiAuNvXForiLKNIyZt
    crypton-x509-1.7.7-KowEUjcKD4sGiHjIVvG1cv directory-1.3.7.1
    filepath-1.4.2.2 mtl-2.2.2 pem-0.2.4-A4zfZZZAj9x41bTj6zPSP6

haddock-interfaces:
    /usr/share/doc/haskell-crypton-x509-store/html/crypton-x509-store.haddock

haddock-html:         /usr/share/doc/haskell-crypton-x509-store/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-crypton-x509-store-1.6.11-35-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-crypton-x509-store.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 crypton-x509-store
version:              1.6.11
visibility:           public
id:                   crypton-x509-store-1.6.11-GJiZC5vJUEY4knqndkHnYn
key:                  crypton-x509-store-1.6.11-GJiZC5vJUEY4knqndkHnYn
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/kazu-yamamoto/crypton-certificate
synopsis:             X.509 collection accessing and storing methods
description:
    X.509 collection accessing and storing methods for certificate, crl, exception list

category:             Data
abi:                  7c847a466d3e84168b50fe8407ba1f47
exposed:              True
exposed-modules:
    Data.X509.CertificateStore Data.X509.File Data.X509.Memory

import-dirs:          /usr/lib/ghc-9.4.8/site-local/crypton-x509-store-1.6.11
library-dirs:         /usr/lib/ghc-9.4.8/site-local/crypton-x509-store-1.6.11
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/crypton-x509-store-1.6.11
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypton-x509-store
hs-libraries:         HScrypton-x509-store-1.6.11-GJiZC5vJUEY4knqndkHnYn
depends:
    asn1-encoding-0.9.6-7usdaJgjrV05vbwBXVIZkX
    asn1-types-0.3.4-EM27xp8ZSwZ5PBfCM7nPju base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7
    crypton-1.0.4-IAATRfKOsBm7gMPlaLRwS1
    crypton-x509-1.7.7-DfOoPtgpknYE7Wr3UzaMlb directory-1.3.7.1
    filepath-1.4.2.2 mtl-2.2.2 pem-0.2.4-H3fRVQX1NBJBcLKDWuPDk

haddock-interfaces:
    /usr/share/doc/haskell-crypton-x509-store/html/crypton-x509-store.haddock

haddock-html:         /usr/share/doc/haskell-crypton-x509-store/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
